=== modified file 'indicator/messagingmenu.cpp'
--- indicator/messagingmenu.cpp	2015-06-11 16:38:02 +0000
+++ indicator/messagingmenu.cpp	2015-06-25 15:02:13 +0000
@@ -105,11 +105,10 @@
  
 }
 
-void MessagingMenu::addMessage(const QString &senderId, const QStringList &participantIds, const QString &accountId, const QString &messageId, const QDateTime &timestamp, const QString &text)
+void MessagingMenu::addMessage(const QString &senderId, const QString &contactAlias, const QStringList &participantIds, const QString &accountId, const QString &messageId, const QDateTime &timestamp, const QString &text)
 {
     // try to get a contact for that phone number
     QUrl iconPath = QUrl::fromLocalFile(telephonyServiceDir() + "/assets/avatar-default@18.png");
-    QString contactAlias = senderId;
 
     AccountEntry *account = TelepathyHelper::instance()->accountForId(accountId);
     if (!account) {
@@ -125,13 +124,13 @@
 
     // place the messaging-menu item only after the contact fetch request is finished, as we can´t simply update
     QObject::connect(request, &QContactAbstractRequest::stateChanged,
-                     [request, senderId, participantIds, accountId, messageId, text, timestamp, iconPath, contactAlias, this]() {
+                     [request, senderId, participantIds, accountId, messageId, text, timestamp, iconPath, contactAlias, this](QContactAbstractRequest::State newState) {
 
         GFile *file = NULL;
         GIcon *icon = NULL;
 
         // only process the results after the finished state is reached
-        if (request->state() != QContactAbstractRequest::FinishedState) {
+        if (newState != QContactAbstractRequest::FinishedState) {
             return;
         }
 

=== modified file 'indicator/messagingmenu.h'
--- indicator/messagingmenu.h	2015-05-19 18:34:06 +0000
+++ indicator/messagingmenu.h	2015-06-25 15:02:13 +0000
@@ -52,7 +52,7 @@
     static MessagingMenu *instance();
     virtual ~MessagingMenu();
 
-    void addMessage(const QString &senderId, const QStringList &participantIds, const QString &accountId, const QString &messageId, const QDateTime &timestamp, const QString &text);
+    void addMessage(const QString &senderId, const QString &contactAlias, const QStringList &participantIds, const QString &accountId, const QString &messageId, const QDateTime &timestamp, const QString &text);
     void addFlashMessage(const QString &senderId, const QString &accountId, const QString &messageId, const QDateTime &timestamp, const QString &text);
     void removeMessage(const QString &messageId);
 

=== modified file 'indicator/textchannelobserver.cpp'
--- indicator/textchannelobserver.cpp	2015-06-25 13:18:24 +0000
+++ indicator/textchannelobserver.cpp	2015-06-25 15:02:13 +0000
@@ -346,9 +346,9 @@
         QContactFetchRequest *request = new QContactFetchRequest(this);
         request->setFilter(QContactPhoneNumber::match(contact->id()));
 
-        QObject::connect(request, &QContactAbstractRequest::stateChanged, [this, request, accountId, participantIds, message]() {
+        QObject::connect(request, &QContactAbstractRequest::stateChanged, [this, request, accountId, participantIds, message](QContactAbstractRequest::State newState) {
             // only process the results after the finished state is reached
-            if (request->state() != QContactAbstractRequest::FinishedState) {
+            if (newState != QContactAbstractRequest::FinishedState) {
                 return;
             }
 
@@ -369,11 +369,10 @@
             request->setManager(ContactUtils::sharedManager());
             request->start();
         } else {
-            request->deleteLater();
-            showNotificationForMessage(message, accountId, participantIds, QContact());
+            // just emit the signal to pretend we did a contact search
+            Q_EMIT request->stateChanged(QContactAbstractRequest::FinishedState);
         }
     }
-
 }
 
 void TextChannelObserver::showNotificationForMessage(const Tp::ReceivedMessage &message, const QString &accountId, const QStringList &participantIds, const QContact &contact)
@@ -421,7 +420,7 @@
         return;
     }
 
-    MessagingMenu::instance()->addMessage(telepathyContact->id(), participantIds, accountId, token.toHex(), message.received(), messageText);
+    MessagingMenu::instance()->addMessage(telepathyContact->id(), telepathyContact->alias(), participantIds, accountId, token.toHex(), message.received(), messageText);
 
     QString alias;
     QString avatar;
@@ -626,8 +625,15 @@
 
 void TextChannelObserver::onReplyReceived(const QStringList &recipients, const QString &accountId, const QString &reply)
 {
+    AccountEntry *account = TelepathyHelper::instance()->accountForId(accountId);
+    if (!account) {
+        return;
+    }
+
     // FIXME - we need to find a better way to deal with dual sim in the messaging-menu
-    if (!TelepathyHelper::instance()->defaultMessagingAccount() && TelepathyHelper::instance()->activeAccounts().size() > 1) {
+    if (!TelepathyHelper::instance()->defaultMessagingAccount()
+            && TelepathyHelper::instance()->activeAccounts().size() > 1
+            && account->type() != AccountEntry::GenericAccount) {
         NotifyNotification *notification = notify_notification_new(C::gettext("Please, select a SIM card:"),
                                                                    reply.toStdString().c_str(),
                                                                    "");
@@ -660,8 +666,12 @@
         return;
     }
 
-    // FIXME: for now we dont specify any accountId
-    sendMessage(recipients, reply, "");
+    if (account->type() == AccountEntry::GenericAccount) {
+        sendMessage(recipients, reply, accountId);
+    } else {
+        // FIXME: for now we dont specify any accountId
+        sendMessage(recipients, reply, "");
+    }
 }
 
 void TextChannelObserver::onMessageRead(const QStringList &recipients, const QString &accountId, const QString &encodedMessageId)

